@@ -102,6 +102,22 @@ class RetentionPolicy:
         self.unknown_fields = kwargs
 
 
+class ConversationPref:
+    type: Optional[List[str]]
+    user: Optional[List[str]]
+
+    def __init__(
+        self,
+        *,
+        type: Optional[List[str]] = None,
+        user: Optional[List[str]] = None,
+        **kwargs,
+    ) -> None:
+        self.type = type
+        self.user = user
+        self.unknown_fields = kwargs
+
+
 class Details:
     name: Optional[str]
     new_value: Optional[Union[str, List[str], Dict[str, Any]]]
@@ -159,6 +175,9 @@ class Details:
     is_token_rotation_enabled_app: Optional[bool]
     old_retention_policy: Optional[RetentionPolicy]
     new_retention_policy: Optional[RetentionPolicy]
+    who_can_post: Optional[ConversationPref]
+    can_thread: Optional[ConversationPref]
+    is_external_limited: Optional[bool]
 
     def __init__(
         self,
@@ -218,6 +237,9 @@ class Details:
         is_token_rotation_enabled_app: Optional[bool] = None,
         old_retention_policy: Optional[Union[Dict[str, Any], RetentionPolicy]] = None,
         new_retention_policy: Optional[Union[Dict[str, Any], RetentionPolicy]] = None,
+        who_can_post: Optional[Union[Dict[str, List[str]], ConversationPref]] = None,
+        can_thread: Optional[Union[Dict[str, List[str]], ConversationPref]] = None,
+        is_external_limited: Optional[bool] = None,
         **kwargs,
     ) -> None:
         self.name = name
@@ -284,6 +306,17 @@ class Details:
             if isinstance(new_retention_policy, RetentionPolicy)
             else RetentionPolicy(**new_retention_policy)
         )
+        self.who_can_post = (
+            who_can_post
+            if isinstance(who_can_post, ConversationPref)
+            else ConversationPref(**who_can_post)
+        )
+        self.can_thread = (
+            can_thread
+            if isinstance(can_thread, ConversationPref)
+            else ConversationPref(**can_thread)
+        )
+        self.is_external_limited = is_external_limited
 
 
 class App:
